function y = lagint(x,t,f)
%LAGINT polinomio interpolante di Lagrange
%   y=lagint(x,t,f)
%   input:  x = punti di valutazione
%           t = ascisse di interpolazione
%           f = ordinate di interpolazione
%   output: y = valori del polinomio interpolante
%   tutti i parametri sono vettori colonna

m = length(x);
n = length(t);
x = x(:);  t = t(:);  f = f(:);
d = zeros(n,1);
for j = 1:n	% calcolo denominatori
	d(j) = prod(t(j)-t([1:j-1,j+1:n]));
end
y = zeros(m,1);
for i = 1:m
	w = prod(x(i)-t)./(x(i)-t);	% numeratori
	L = w./d;	% polinomi di Lagrange
	y(i) = f'*L;	% valore del pol. int. in x(i)
end

